## conduct DESeq+Enrichment on 13 patient averaged CTC expression data. Note lowly expressed genes were filtered out
## 23 December 2015 Qike Li

library(DESeq)
rm(list=ls())

# read in CTC count data
data.deseq = read.delim('~/Dropbox/CTCs/CTC_EDA/DEG_Enrichment/data/ctc.13pat.higRPM.count.txt')
data.deseq = round(data.deseq) # round the average of counts since DESeq only takes integer input
gene.symbol = row.names(data.deseq) # store gene symbols

## read in the correspoinding genes for each pathway and the description of each pathway
pid <- read.delim("~/Dropbox/Lab-Tools/GeneSets/PathwayInteractionDatabase/PID_filtered15-X.txt")
pid.des = read.delim("~/Dropbox/Lab-Tools/GeneSets/PathwayInteractionDatabase/PID_description.txt")
# clinical data
sample.data <- read.delim(file="~/Dropbox/CTCs/GSE67980/GSE67980_sampleProperties.txt")
# find the patient IDs in native group
pat.n = unique(sample.data$characteristics..donor[grepl('Group A',sample.data$characteristics..enzalutamide)])
# find the patient IDs in resistent group
pat.r = unique(sample.data$characteristics..donor[grepl('Group B',sample.data$characteristics..enzalutamide)])
# extract out the patient IDs from the column names of data.deseq
colname.patID = colnames(data.deseq)
group = character()
# label the naive patient
group[colname.patID %in% pat.n] = 'N'
# label the resistent patient
group[colname.patID %in% pat.r] = 'R'


### Run DESeq
# a matrix that contains the info of study design 
targets = data.frame(Treatment = group, Label = colnames(data.deseq))
cds = newCountDataSet(data.deseq,conditions = targets$Treatment)
cds = estimateSizeFactors( cds )
sizeFactors( cds )
head( counts( cds, normalized=TRUE ) )
cds = estimateDispersions( cds, method = "per-condition", fitType = 'local') # fitType = 'parametric' is the default, and it failed
head( fData(cds) ) # dispersion estimated for each gene(two conditions)
res = nbinomTest( cds, "N", "R" )
head(res)
# save DESeq results
write.table(res,file = 'DESeq_13pat_result.txt', quote = F, sep='\t')

# define a function to conduct FET
f.FET = function(x) {
  gene.onePID = x$symbol
  a = sum(gene.onePID %in% sig.genes) # a is the number of  genes that are in the pathway and are differentially expressed
  b = length(gene.onePID) - a  # b is the number of  genes that are in the pathway but not differentially expressed
  if(a+b!=length(gene.onePID)) stop('check contingency table')
  c = length(sig.genes) - a # c is the number of genes that are in not in the pathway but are differentially expressed
  d = length(nonsig.genes) - b # d is the number of genes that are not in the pathway are are not differentially expressed
  if(a + b + c + d != dim(data.deseq)[1]) stop('check contingency table')
  m = matrix(c(a,b,c,d),ncol =2, byrow = T)
  return( fisher.test(m, alternative = 'greater')$p.value)
}

FDR.cutoff = .3 # cut off at gene level
# index the differentially expressed genes
ind.DE = res$padj< FDR.cutoff #233 differentially expressed genes at the significance level FDR < .3
## select the significant genes and non-significant genes
sig.genes = rownames(data.deseq)[ind.DE]
nonsig.genes = rownames(data.deseq)[!ind.DE]

# a data frame to indicate the DEstatus of each gene
DE.df = data.frame(symbol = gene.symbol, DEstatus = as.integer(ind.DE))

# create a list in which each element is a pathway
path.list = split(pid,f = pid$path_id)

# apply f.FET for each pathway and store the results
res.enrich = data.frame(path_id = names(unlist(lapply(path.list,f.FET))), unlist(lapply(path.list,f.FET)))
# attach pathway names to each row
res.enrich = merge(res.enrich,pid.des)

colnames(res.enrich)[2] = 'p_nomial'

write.table(res.enrich[order(res.enrich$p_nomial),], file = '~/Dropbox/CTCs/CTC_EDA/DEG_Enrichment/results/pathwayPvalues_13pat_DEGenrich.txt', quote = F, sep='\t', row.names = F)