##################################################
### setup GSEA on CTC filtered dataset and grouped by patients
### Qike Li
### 12/23/2015  

#source("~/Dropbox/Lab-Tools/GSEA/GSEA-P-R/GSEA.1.0.v2.R")
setwd("~/Dropbox/CTCs/CTC_EDA/GSEA")
rm(list=ls())
#########################
## format gene set definitions (doesn't need to be run again if file is already generated)
gs.db = "~/Dropbox/Lab-Tools/GeneSets/PathwayInteractionDatabase/PID_filtered15-X.txt"

## reformat to gmt
pathways.set <- read.delim(gs.db)

## combine two variables by tabs then write line by line
symbols.list <- split(pathways.set$symbol,pathways.set$path_id)
goIDs <- names(symbols.list)

## descriptions
go.desc = read.delim('~/Dropbox/Lab-Tools/GeneSets/PathwayInteractionDatabase/PID_description.txt')
row.names(go.desc) <- go.desc$path_id

go.filter.desc <- as.character(go.desc[goIDs,"description"])

#tmp.go <- symbols.list[[1]]
genes.go <- lapply(symbols.list,function(tmp.go) {
  paste(as.character(tmp.go),collapse ="\t")
})

writeLines(paste(goIDs,go.filter.desc,genes.go,sep="\t"),"~/Dropbox/CTCs/CTC_EDA/GSEA/data/PID.filteredNoDups.gmt")

############################
## format expression data
## read in expression and add NAME, description column

formatGCT <- function(expr.file) {
  ## automatically rename and place into same directory
  path <- unlist(strsplit(expr.file,"/"))
  file <- path[length(path)]
  myDir <- paste(c(path[-length(path)],""),collapse = "/")
  ## read tab-delimited, standard expression file
  expr <- read.table(expr.file,header=T,sep="\t",quote = "")
  ## add required GSEA columns
  expr$NAME <- row.names(expr)
  expr$DESCRIPTION <- "na"
  expr <- expr[,c(ncol(expr)-1,ncol(expr),1:(ncol(expr)-2))]
  ## create new file name
  newFile <- unlist(strsplit(file,"\\."))
  newFile[length(newFile)] <- "gct"
  newFile <- paste(newFile[-length(path)],collapse = ".")
  ## write
  write.table(expr,paste0(myDir,newFile),sep="\t",row.names=F,quote=F)
  ## add header
  header.txt <- c("#1.2",paste(nrow(expr),"\t",ncol(expr)-2,sep=""))
  fConn <- file(paste0(myDir,newFile), 'r+')
  Lines <- readLines(fConn) 
  writeLines(c(header.txt, Lines), con = fConn) 
  close(fConn)
  print(paste0("GSEA GCT input file written to ", myDir,newFile))
}

# conver txt file to the GCT file required by GSEA
formatGCT('~/Dropbox/CTCs/CTC_EDA/GSEA/data/ctc.13pat.higRPM.rpm.txt')

## create phenotype file (.cls)

# clinical data
sample.data <- read.delim(file="~/Dropbox/CTCs/GSE67980/GSE67980_sampleProperties.txt")
# find the patient IDs in native group
pat.n = unique(sample.data$characteristics..donor[grepl('Group A',sample.data$characteristics..enzalutamide)])
# find the patient IDs in resistent group
pat.r = unique(sample.data$characteristics..donor[grepl('Group B',sample.data$characteristics..enzalutamide)])
#read in the expression data
data.expr = read.delim('~/Dropbox/CTCs/CTC_EDA/GSEA/data/ctc.13pat.higRPM.rpm.txt')
head(data.expr)
# extract out the patient IDs from the column names of data.expr
colname.patID = colnames(data.expr)
group = character()
# label the naive patient
group[colname.patID %in% pat.n] = 'N'
# label the resistent patient
group[colname.patID %in% pat.r] = 'R'

line1 = "13 2 1"
line2 = '# N R'
line3 = paste(group, collapse = ' ')
writeLines(c(line1,line2,line3),"~/Dropbox/CTCs/CTC_EDA/GSEA/data/study_design_13pat.cls")


