######################################################
#' @title Robustness of Weighted Least Squares to patient removal
#' @author A. Grant Schissler
#' @date 22 Dec 2015
#' @description XXX
######################################################

setwd("./Figure2")

## load in clinical data
load("../CommonData/CTC_pairs.RData")

## read gene expression data, filtered rpkm
gene.express <- read.table("./GSEA/data/ctc.77.higRPM.rpm.txt", header = T , sep = "\t")

### our standard log + 1 transformation
gene.log2 <- log2(gene.express + 1)

## try simply Welch 2-sample t-test
## tmp.id <- "200020"

## store the standard approach results
standard.results <- NULL

## while removing one patient at a time to understand stability of ranked lists
## tmp.patient <- "Pr6"

start.time <- proc.time()
for (tmp.patient in c("None", a.patients, b.patients)) { 

    print(paste0("Working on patient ", tmp.patient))
    ## remove the current patient if desired
    if (tmp.patient != "None") {
        tmp.gene.data <- gene.log2[,-grep( paste0(tmp.patient, "\\."), names(gene.log2))]
    } else tmp.gene.data <- gene.log2
    
    ## assign group labels
    patients <- unlist(lapply(strsplit(colnames(tmp.gene.data), "\\."), function(x) x[1]))
    group.labels <- factor(as.numeric(patients %in% b.patients), labels = c("A","B"))

    for (tmp.id in unique(pid.genes$path_id)) {

        print(paste0("Working on patient ", tmp.patient, " and pathway ", tmp.id))
        ## summarize PID gene set my taking the average
        tmp.genes <- unique(pid.genes[pid.genes$path_id == tmp.id,"symbol"])

        ## ensure that only measured genes are indexed
        tmp.genes <- row.names(tmp.gene.data)[row.names(tmp.gene.data) %in% tmp.genes]

        ## find columns means
        tmp.ctc <- colMeans(tmp.gene.data[tmp.genes,], na.rm = T)

        ## CTC 2-sample t test
        if (!all(is.nan(tmp.ctc))) {

            ## weighted least squares
            tmp.mean <- unlist(lapply(split(tmp.ctc, patients),mean))
            tmp.n <- unlist(lapply(split(tmp.ctc, patients),length))
            tmp.group <- unlist(lapply(split(group.labels, patients),unique))
            tmp.wls.pvalue <- summary(aov(lm(tmp.mean ~ tmp.group, weights = tmp.n)))[[1]][1,5]
            
            ## store into data frame
            standard.results <- rbind(standard.results,
                                      data.frame(PID=tmp.id, wls.pvalue = tmp.wls.pvalue, patient = tmp.patient))
        } else {
            ## no genes measured, pvalue of 1
            standard.results <- rbind(standard.results,data.frame(PID=tmp.id, wls.pvalue = 1, patient = tmp.patient))
        }
    }
}

(end.time <- proc.time() - start.time)  ## 30 seconds

## reorder
standard.results <- standard.results[order(standard.results$wls.pvalue),]

## rename
wls.results <- standard.results

## cleanup and save workspace
rm(list=setdiff(ls(), "wls.results"))
save.image("./WeightedLS_Robustness.RData")

######################################################
## write pvalues for no patients removed

all.wls.data <- wls.results[wls.results$patient == "None",] 
write.table(data.frame(PID = all.wls.data$PID, nominal.pvalue = all.wls.data$wls.pvalue), "./WeightedLS_pvaluesV3.txt", quote = F,sep = "\t", row.names = F)

## qplot(all.wls.data$wls.pvalue)
