## compare the results from different methods
## Qike Li 12/21/2015

library(GGally)
library(ggplot2)
library(reshape2)
rm(list=ls()) 

### read in the results generated from different methods

## change directory
setwd("./Figure2")

## read in GSEA result. 
res.GSEA.N = read.delim('./GSEA/results/GSEA_rpm_highRPM_13pat_1000_java/gsea_report_for_N_1450904939923.xls')
res.GSEA.R= read.delim('./GSEA/results/GSEA_rpm_highRPM_13pat_1000_java/gsea_report_for_R_1450904939923.xls')
res.GSEA = rbind(res.GSEA.N,res.GSEA.R)[,c('NAME', 'NOM.p.val')]

## assign p-value 1 to the pathway that was rejected in the GSEA analysis due to small gene set size
GS.exclude= read.delim('./GSEA/results/GSEA_rpm_highRPM_13pat_1000_java/gene_set_sizes.xls')
res.GSEA = rbind(res.GSEA,data.frame(NAME = GS.exclude[GS.exclude$STATUS == 'Rejected!',]$NAME,NOM.p.val = 1 ))
rownames(res.GSEA) = res.GSEA$NAME

## read in DEG+Enrichment results
res.DEGenrich = read.delim('./DEG_Enrichment/results/pathwayPvalues_13pat_DEGenrich.txt',row.names = 'path_id')

#### first five pathways prioritized by nomial p-values; 1/13/2016 #####
write.table(res.GSEA[order(res.GSEA$NOM.p.val),], file = './GSEA/results/orderedPathList_GSEA.txt', quote = F, sep ='\t', row.names = F)
write.table(res.DEGenrich[order(res.DEGenrich$p_nomial),],file = './DEG_Enrichment/results/orderedPathList_DEGen.txt', quote = F, sep ='\t', row.names = F)
########################################################################

## read in boot strap results
res.boot = read.delim('./cluster_boot_pvaluesV3.txt',row.names = 'PID')
## read in WLS results
res.WLS = read.delim('./WeightedLS_pvaluesV3.txt',row.names = 'PID')

## create a data frame to store the combine the results resulting from different methods
pid = rownames(res.boot)
df.p = data.frame(CCS = res.boot[pid,'nominal.pvalue'], WLS = res.WLS[pid,'nominal.pvalue'],
                  #permutation = res.permu[pid,'nominal.pvalue'],# t_test = res.t[pid,'nominal.pvalue'],
                   GSEA = res.GSEA[pid,'NOM.p.val'],"DEG+Enrich" = res.DEGenrich[pid,'p_nomial']) 
row.names(df.p) = pid


# write out the list of pathways in the ascending order of p-values
write.table(row.names(df.p)[order(df.p$CCS)], file = './CCS_rankedPID.txt', quote=F, sep = '\t', row.names = F, col.names = F)
write.table(row.names(df.p)[order(df.p$GSEA)], file = './GSEA_rankedPID.txt', quote=F, sep = '\t', row.names = F, col.names = F)
write.table(row.names(df.p)[order(df.p$WLS)], file = './WLS_rankedPID.txt', quote=F, sep = '\t', row.names = F, col.names = F)
write.table(row.names(df.p)[order(df.p$DEG.Enrich)], file = './deg_rankedPID.txt', quote=F, sep = '\t', row.names = F, col.names = F)

# plot the scatter plot in figure 2
scale.mm = 25.4
pdf(file= './Figure2.Panel.A.pdf', width = 170/scale.mm, compress = F)
ggpairs(df.p, alpha = 0.3, diag=list(continuous='density'), axisLabels='show') + theme_bw(base_size = 11 ) 
dev.off()

# conduct correlation test using spearman's rho for every pari of methods
cor(df.p,method = 'spearman')
for (i in 1:ncol(df.p) ) {
    for (j in 1:i ) {
        if ( j != i ) {
            tmp.method1 <- names(df.p)[i]
            tmp.method2 <- names(df.p)[j]
            print(paste0( "comparing ", tmp.method1, " to ", tmp.method2 ))
            print(cor.test(df.p[,i], df.p[,j] ,method = 'spearman'))
        }
    }
}

# conver df.p to long format
df.p.l = melt(df.p, value.name = 'nominal_p_val')
names(df.p.l)[1] = 'Method'

# plot the density plot in figure 2
ggplot(df.p.l,aes(x=nominal_p_val, group = factor(Method, levels = c('DEG.Enrich','GSEA', 'WLS', 'CCS' )),color = factor(Method, levels = c('DEG.Enrich','GSEA', 'WLS', 'CCS' )))) + 
  geom_line( stat="density", size = 1.2) + 
  theme_bw(base_size = 15) +
  theme(legend.position = c(.6, .8), #axis.title.x = element_blank(),
        legend.title = element_blank(), 
        legend.background = element_rect(fill='transparent'),
        aspect.ratio = 1)+
  labs(y = 'Density',
        x = 'Nomial p-value') +
  scale_color_manual(values = rev(c('#A078AA','#72BF44','#FFA040','#F9F080')))+
  guides(col = guide_legend(reverse = TRUE))

ggsave(file = './Figure2.Panel.B.pdf',width = 3)
